# Spiderstore

The spiderstore project is a Python library designed for web scrapers with the goal of scraping the internet. It provides a flexible and extensible framework for building web scrapers that can navigate through websites, extract data, and scale infinitely.

## Installation

You can install the library using pip
```
$ python3 -m pip install spiderstore
```

## Resources

- [Documentation](https://spiderstore.readthedocs.io)
- [Source Code](https://spiderstore.readthedocs.io)

## Contributing

We appreciate all contributions. If you are planning to contribute back bug-fixes, please do so without any further discussion.

If you plan to contribute new features, utility functions, or extensions to the core, please first open an issue and discuss the feature with us. Sending a PR without discussion might end up resulting in a rejected PR because we might be taking the core in a different direction than you might be aware of.

## License
This project is released under [GNU GPLv3 License](LICENSE)